function sFilesNotch = script_pre_sub8(SubjectNames, RawFiles, NoiseFiles, RawEventFiles, iSubj)

% Process: Create link to raw file
sFilesRun = bst_process('CallProcess', 'process_import_data_raw', [], [], ...
    'subjectname',    SubjectNames{iSubj}, ...
    'datafile',       {RawFiles{iSubj}, 'FIF'}, ...
    'channelreplace', 1, ...
    'channelalign',   1, ...
    'evtmode',        'value');

% Process: Create link to raw file
sFilesNoise = bst_process('CallProcess', 'process_import_data_raw', [], [], ...
    'subjectname',    SubjectNames{iSubj}, ...
    'datafile',       {NoiseFiles{iSubj}, 'FIF'}, ...
    'channelreplace', 1, ...
    'channelalign',   1, ...
    'evtmode',        'value');

% Process: Import from file
bst_process('CallProcess', 'process_evt_import', sFilesRun(1), [], ...
    'evtfile', {RawEventFiles{iSubj}{1}, 'BST'}, ...
    'evtname', 'New');

% Process: Import from file
bst_process('CallProcess', 'process_evt_import', sFilesRun(2), [], ...
    'evtfile', {RawEventFiles{iSubj}{2}, 'BST'}, ...
    'evtname', 'New');
 
% Process: Warp default anatomy
sFilesRun = bst_process('CallProcess', 'process_warp', sFilesRun, [], ...
    'usedefault', 2, ...  % Warp
    'tolerance',  2);

% Process: Refine registration
sFilesRun = bst_process('CallProcess', 'process_headpoints_refine', sFilesRun, []);

% Process: Notch filter: 50Hz 100Hz 150Hz
sFilesRaw = [sFilesRun, sFilesNoise];
sFilesNotch = bst_process('CallProcess', 'process_notch', sFilesRaw, [], ...
    'sensortypes', 'MEG, EEG', ...
    'freqlist',    [50, 100, 150], ...
    'cutoffW',     1, ...
    'useold',      0, ...
    'read_all',    0);

% Process: Delete and rename files
bst_process('CallProcess', 'process_delete', sFilesRaw, [], ...
    'target', 2);  % Delete folders
sFilesRun1 = {sFilesNotch(1).FileName};
sFilesRun2 = {sFilesNotch(2).FileName};
sFilesNoise = {sFilesNotch(3).FileName};


% Process: Add time offset
bst_process('CallProcess', 'process_evt_timeoffset', sFilesRun1, [], ...
    'info',      [], ...
    'eventname', 'B', ...
    'offset',    0.056);

% Process: Add time offset
bst_process('CallProcess', 'process_evt_timeoffset', sFilesRun2, [], ...
    'info',      [], ...
    'eventname', 'F', ...
    'offset',    0.056);

% Process: Detect heartbeats
bst_process('CallProcess', 'process_evt_detect_ecg', [sFilesRun1, sFilesRun2], [], ...
    'channelname', 'ECG062', ...
    'timewindow',  [48, 1114.999], ...
    'eventname',   'cardiac');

% Process: Detect eye blinks
bst_process('CallProcess', 'process_evt_detect_eog', [sFilesRun1, sFilesRun2], [], ...
    'channelname', 'EOG061', ...
    'timewindow',  [48, 1114.999], ...
    'eventname',   'blink');

% Process: Remove simultaneous
bst_process('CallProcess', 'process_evt_remove_simult', [sFilesRun1, sFilesRun2], [], ...
    'remove', 'cardiac', ...
    'target', 'blink', ...
    'dt',     0.25, ...
    'rename', 0);

% Process: SSP ECG: cardiac
bst_process('CallProcess', 'process_ssp_ecg', [sFilesRun1, sFilesRun2], [], ...
    'eventname',   'cardiac', ...
    'sensortypes', 'MEG', ...
    'usessp',      1, ...
    'select',      1);

% Process: SSP EOG: blink
bst_process('CallProcess', 'process_ssp_eog', [sFilesRun1, sFilesRun2], [], ...
    'eventname',   'blink', ...
    'sensortypes', 'MEG', ...
    'usessp',      1, ...
    'select',      1);

% Process: Import MEG/EEG: Events
bst_process('CallProcess', 'process_import_data_event', sFilesRun1, [], ...
    'subjectname', SubjectNames{iSubj}, ...
    'condition',   '', ...
    'eventname',   'B', ...
    'timewindow',  [], ...
    'epochtime',   [0, 120], ...
    'createcond',  0, ...
    'ignoreshort', 1, ...
    'usectfcomp',  1, ...
    'usessp',      1, ...
    'freq',        [], ...
    'baseline',    []);

% Process: Import MEG/EEG: Events
bst_process('CallProcess', 'process_import_data_event', sFilesRun2, [], ...
    'subjectname', SubjectNames{iSubj}, ...
    'condition',   '', ...
    'eventname',   'F', ...
    'timewindow',  [], ...
    'epochtime',   [0, 120], ...
    'createcond',  0, ...
    'ignoreshort', 1, ...
    'usectfcomp',  1, ...
    'usessp',      1, ...
    'freq',        [], ...
    'baseline',    []);

% Process: Compute covariance (noise or data)
bst_process('CallProcess', 'process_noisecov', sFilesNoise, [], ...
    'baseline',       [], ...
    'sensortypes',    'MEG', ...
    'target',         1, ...  % Noise covariance     (covariance over baseline time window)
    'dcoffset',       1, ...  % Block by block, to avoid effects of slow shifts in data
    'identity',       0, ...
    'copycond',       1, ...
    'copysubj',       0, ...
    'replacefile',    1);  % Replace

% Process: Snapshot: Noise covariance
bst_process('CallProcess', 'process_snapshot', sFilesNoise, [], ...
    'target',  3, ...  % Noise covariance
    'Comment', 'Noise covariance');